/**
 * Fractal Binding Factory.
 * Copyright (C) 2009 Bull S.A.S.
 * Copyright (C) 2009 INRIA, SARDES
 * Contact: fractal@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: OSGiPluginResolver.java 9988 2009-06-12 14:50:57Z loris $
 * --------------------------------------------------------------------------
 */
package org.objectweb.fractal.bf.osgi;

import java.util.Arrays;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.objectweb.fractal.bf.BindingFactoryPlugin;
import org.objectweb.fractal.bf.PluginNotFoundException;
import org.objectweb.fractal.bf.PluginResolver;
import org.osgi.framework.BundleContext;
import org.osgi.framework.InvalidSyntaxException;
import org.osgi.framework.ServiceReference;
import org.ow2.fractal.julia.osgi.api.control.OSGiContextController;

/**
 * In OSGi, BF plugin are accessed through services.
 * @author Loris Bouzonnet
 */
public class OSGiPluginResolver implements PluginResolver, OSGiContextController {

    /**
     * Logger.
     */
    private static Logger log = Logger.getLogger(OSGiPluginResolver.class.getName());

    /**
     * Bundle context.
     * Set at bundle startup by the Julia OSGi Launcher.
     */
    private BundleContext context;

    public BindingFactoryPlugin<?, ?> resolvePlugin(final String exportMode)
            throws PluginNotFoundException {

        log.fine("Resolving plugin with identifier:'" + exportMode + "'");

        if (context == null) {
            log.log(Level.SEVERE, "Bundle context missing");
            throw new PluginNotFoundException("Bundle context missing");
        }

        String filter = "(plugin=" + exportMode + ")";

        // TODO return a proxy
        ServiceReference[] refs;
        try {
            refs = context.getServiceReferences("org.objectweb.fractal.bf.BindingFactoryPlugin", filter);
        } catch (InvalidSyntaxException e) {
            log.log(Level.SEVERE, "Bad filters: " + filter, e);
            throw new PluginNotFoundException("Bad filters: " + filter, e);
        }
        if (refs == null) {
            log.log(Level.SEVERE, "No plugin for " + filter);
            throw new PluginNotFoundException("No plugin for " + filter);
        }
        if (refs.length > 1) {
            log.warning("Many plugins for " + filter + " are available: using the first one of " + Arrays.toString(refs));
        }
        return (BindingFactoryPlugin<?, ?>) context.getService(refs[0]);
    }

    public BundleContext getBundleContext() {
        return context;
    }

    public void setBundleContext(final BundleContext context) {
        this.context = context;
    }

}
